# Generated by Django 3.2.21 on 2023-09-21 10:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0184_auto_20230914_2057'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='career_engagement_network_message',
            field=models.TextField(blank=True, help_text='Message text shown on the learner portal dashboard for career engagement network.'),
        ),
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_career_engagement_network_on_learner_portal',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the link to CEN on the learner portal dashboard.', verbose_name='Allow navigation to career engagement network from learner portal dashboard'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='career_engagement_network_message',
            field=models.TextField(blank=True, help_text='Message text shown on the learner portal dashboard for career engagement network.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_career_engagement_network_on_learner_portal',
            field=models.BooleanField(default=False, help_text='If checked, the learners will be able to see the link to CEN on the learner portal dashboard.', verbose_name='Allow navigation to career engagement network from learner portal dashboard'),
        ),
    ]
