# Generated by Django 3.2.20 on 2023-10-09 13:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0191_auto_20231006_0948'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_demo_data_for_analytics_and_lpr',
            field=models.BooleanField(default=False, help_text='Display Demo data from analyitcs and learner progress report for demo customer.', verbose_name='Enable demo data from analytics and lpr'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_demo_data_for_analytics_and_lpr',
            field=models.BooleanField(default=False, help_text='Display Demo data from analyitcs and learner progress report for demo customer.', verbose_name='Enable demo data from analytics and lpr'),
        ),
    ]
