# Generated by Django 3.2.22 on 2023-10-13 13:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0193_auto_20231005_1708'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerssoconfiguration',
            name='errored_at',
            field=models.DateTimeField(blank=True, help_text='The date and time when the orchestrator encountered an error during configuration.', null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomerssoconfiguration',
            name='errored_at',
            field=models.DateTimeField(blank=True, help_text='The date and time when the orchestrator encountered an error during configuration.', null=True),
        ),
    ]
