# Generated by Django 3.2.18 on 2023-03-01 16:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0169_auto_20230222_1621'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalsystemwideenterpriseuserroleassignment',
            name='enterprise_customer',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='The EnterpriseCustomer for which the role is assigned to for the provided user. Defaults to the first active Enterprise Customer that the user is linked to.If another Enterprise Customer object is desired, please first create the record then modify the enterprise customer field by using the drop down.', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='enterprise.enterprisecustomer'),
        ),
        migrations.AlterField(
            model_name='systemwideenterpriseuserroleassignment',
            name='enterprise_customer',
            field=models.ForeignKey(blank=True, help_text='The EnterpriseCustomer for which the role is assigned to for the provided user. Defaults to the first active Enterprise Customer that the user is linked to.If another Enterprise Customer object is desired, please first create the record then modify the enterprise customer field by using the drop down.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='system_wide_role_assignments', to='enterprise.enterprisecustomer'),
        ),
    ]
