# Generated by Django 3.2.18 on 2023-07-07 07:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('consent', '0004_datasharingconsenttextoverrides'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datasharingconsent',
            name='granted',
            field=models.BooleanField(help_text='Whether consent is granted.', null=True),
        ),
        migrations.AlterField(
            model_name='historicaldatasharingconsent',
            name='granted',
            field=models.BooleanField(help_text='Whether consent is granted.', null=True),
        ),
    ]
