# Generated by Django 3.2.23 on 2024-02-16 07:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0032_alter_integratedchannelapirequestlogs_endpoint'),
    ]

    operations = [
        migrations.AddField(
            model_name='integratedchannelapirequestlogs',
            name='channel_name',
            field=models.TextField(blank=True, help_text='Name of the integrated channel associated with this API call log record.'),
        ),
    ]
