# Generated by Django 3.2.15 on 2022-09-28 16:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0162_add_enable_executive_education_2U_fulfillment'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.', verbose_name='Enable Learner Credit in the Learner Portal'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.', verbose_name='Enable Learner Credit in the Learner Portal'),
        ),
    ]
