# Generated by Django 3.2.21 on 2023-10-05 17:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0192_auto_20231009_1302'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='contact_email',
            field=models.EmailField(blank=True, help_text='Email linked on learner portal as public point of contact, will default to all admin users associated with this customer if left blank.', max_length=254, null=True, verbose_name='Customer admin contact email:'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='contact_email',
            field=models.EmailField(blank=True, help_text='Email linked on learner portal as public point of contact, will default to all admin users associated with this customer if left blank.', max_length=254, null=True, verbose_name='Customer admin contact email:'),
        ),
    ]
